locals {
  tag_name = "${terraform.workspace}"
}

#Creates a Snapshot of an EBS Volume.

resource "aws_ebs_snapshot" "sbc_snapshot" {
  volume_id   = data.terraform_remote_state.linuxvm.outputs.VOLUME_ID
  description = "This is an autogenerated snapshot using terraform workspace '${local.tag_name}'"

  tags = {
    Name = "${local.tag_name}"
  }

  timeouts {
    create = "60m"
  }
}

#create time delay to get snapshot ready

resource "time_sleep" "wait_5_seconds" {
  depends_on = [aws_ebs_snapshot.sbc_snapshot]

  create_duration = "5s"
}


#The AMI resource allows the creation and management of
#a completely-custom Amazon Machine Image (AMI).

resource "aws_ami" "sbc_ami" {
  depends_on = [time_sleep.wait_5_seconds]

  name                = local.tag_name
  virtualization_type = "hvm"
  root_device_name    = "/dev/sda1"
  ena_support         = true         // ENA support is only available from sbc release 9.0 onwards
  sriov_net_support   = "simple"

  ebs_block_device {
    device_name           = "/dev/sda1"
    delete_on_termination = true
    snapshot_id           = aws_ebs_snapshot.sbc_snapshot.id
  }

  tags = {
    Name = "${local.tag_name}"
  }
}
