/*************************************************************/
// Copyright (c) 2020 Oracle and/or its affiliates.
/*************************************************************/



// common variable
variable "compartment_ocid" {
  type        = string
  description = "compartment ocid"
}

variable "tenancy_ocid" {
  type        = string
  description = "tenancy ocid"
}

variable "region" {
  type        = string
  description = "region name"
}

variable "user_ocid" {
  type        = string
  default     = ""
  description = "OCI User OCID"
}


variable "fingerprint" {
  type        = string
  default     = ""
  description = "OCI API key fingerprint"
}

variable "oci_api_private_key_path" {
  type        = string
  default     = ""
  description = "OCI API key file path"
}

variable "resource_label" {
  description = "Prefix to each display name of OCI resource being created"
}


//variable used for subnet creation 

variable "vcn_cidr" {
  description = "The cidr block of vcn"
  default     = "10.1.0.0/16"
}

variable "subnet_cidr_wancom_0" {
  description = "The cidr block of management for wancom0"
  default     = "10.1.0.0/24"
}

variable "subnet_cidr_wancom_1" {
  description = "The cidr block of management for wancom1"
  default     = "10.1.1.0/24"
}
variable "subnet_cidr_wancom_2" {
  description = "The cidr block of management for wancom2"
  default     = "10.1.2.0/24"
}
variable "subnet_cidr_media_s0p0" {
  description = "The cidr block of media subnet s0p0"
  default     = "10.1.3.0/24"
}
variable "subnet_cidr_media_s1p0" {
  description = "The cidr block of media subnet s1p0"
  default     = "10.1.4.0/24"
}
variable "subnet_cidr_media_s0p1" {
  description = "The cidr block of media subnet s0p1"
  default     = "10.1.5.0/24"
}
variable "subnet_cidr_media_s1p1" {
  description = "The cidr block of media subnet s1p1"
  default     = "10.1.6.0/24"
}

variable "prohibit_public_ip_management" {
  description = "Prohibit Public IP on VNIC for wancom0"
  type        = bool
  default     = "true"
}

variable "prohibit_public_ip_media" {
  description = "Prohibit Public IP on VNIC for media"
  type        = bool
  default     = "true"
}




variable "udp_port_range_start" {
  description = "Min port range for udp traffic"
  default     = 5000
}

variable "udp_port_range_end" {
  description = "Max port range for udp traffic"
  default     = 65535
}

variable "tcp_port_range_start" {
  description = "Min port range for tcp traffic"
  default     = 5000
}

variable "tcp_port_range_end" {
  description = "Max port range for tcp traffic"
  default     = 65535
}


// variable used for bucket creation
variable "create_bucket" {
  description = "should object storage bucket needs to get created"
  type        = bool
  default     = "false"
}

variable "bucket_name" {
  description = "OCI object storage bucket"
  default     = "sbc-tfbucket"
}


//variable used for security list creation 

variable "media_enable_tcp" {
  description = "Enable or Disable tcp traffic for media security list"
  type        = bool
  default     = "true"
}

variable "media_enable_udp" {
  description = "Enable or Disable udp traffic for media security list"
  type        = bool
  default     = "true"
}

variable "media_enable_icmp" {
  description = "Enable or Disable icmp traffic for media security list"
  type        = bool
  default     = "true"
}

variable "management_enable_ssh" {
  description = "Enable or Disable ssh for management security list"
  type        = bool
  default     = "true"
}

variable "management_enable_ftp" {
  description = "Enable or Disable ftp for management security list"
  type        = bool
  default     = "true"
}

variable "management_enable_http_https" {
  description = "Enable or Disable http/https for media security list"
  type        = bool
  default     = "true"
}

variable "management_enable_icmp" {
  description = "Enable or Disable icmp for management security list"
  type        = bool
  default     = "true"
}



// local variable //

locals {
  tcp_protocol   = "6"
  udp_protocol   = "17"
  icmp_protocol  = "1"
  all_protocol   = "all"
  default_ipaddr = "0.0.0.0/0"
}


//Input validations
locals {
  //regex pattern for ipv4 cidr notation
  regex_ipv4_cidr = "^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])\\.){3,}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])\\/(3[0-2]|[1-2]?[0-9])$"

  val_vcn_cidr               = regex(local.regex_ipv4_cidr, var.vcn_cidr)
  val_subnet_cidr_wancom_0   = regex(local.regex_ipv4_cidr, var.subnet_cidr_wancom_0)
  val_subnet_cidr_wancom_1   = regex(local.regex_ipv4_cidr, var.subnet_cidr_wancom_1)
  val_subnet_cidr_wancom_2   = regex(local.regex_ipv4_cidr, var.subnet_cidr_wancom_2)
  val_subnet_cidr_media_s0p0 = regex(local.regex_ipv4_cidr, var.subnet_cidr_media_s0p0)
  val_subnet_cidr_media_s1p0 = regex(local.regex_ipv4_cidr, var.subnet_cidr_media_s1p0)
  val_subnet_cidr_media_s0p1 = regex(local.regex_ipv4_cidr, var.subnet_cidr_media_s0p1)
  val_subnet_cidr_media_s1p1 = regex(local.regex_ipv4_cidr, var.subnet_cidr_media_s1p1)
}
